==> opensearch-java-2.10.1-sources.jar: org/opensearch/client/opensearch/_types/query_dsl/IdsQuery.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

package org.opensearch.client.opensearch._types.query_dsl;

import jakarta.json.stream.JsonGenerator;
import java.util.List;
import java.util.function.Function;
import javax.annotation.Nullable;
import org.opensearch.client.json.JsonpDeserializable;
import org.opensearch.client.json.JsonpDeserializer;
import org.opensearch.client.json.JsonpMapper;
import org.opensearch.client.json.ObjectBuilderDeserializer;
import org.opensearch.client.json.ObjectDeserializer;
import org.opensearch.client.util.ApiTypeHelper;
import org.opensearch.client.util.ObjectBuilder;

// typedef: _types.query_dsl.IdsQuery

@JsonpDeserializable
public class IdsQuery extends QueryBase implements QueryVariant {
    private final List<String> values;

    // ---------------------------------------------------------------------------------------------

    private IdsQuery(Builder builder) {
        super(builder);

        this.values = ApiTypeHelper.unmodifiable(builder.values);

    }

    public static IdsQuery of(Function<Builder, ObjectBuilder<IdsQuery>> fn) {
        return fn.apply(new Builder()).build();
    }

    /**
     * Query variant kind.
     */
    @Override
    public Query.Kind _queryKind() {
        return Query.Kind.Ids;
    }

    /**
     * API name: {@code values}
     */
    public final List<String> values() {
        return this.values;
    }

    protected void serializeInternal(JsonGenerator generator, JsonpMapper mapper) {

        super.serializeInternal(generator, mapper);
        if (ApiTypeHelper.isDefined(this.values)) {
            generator.writeKey("values");
            generator.writeStartArray();
            for (String item0 : this.values) {
                generator.write(item0);

            }
            generator.writeEnd();

        }

    }

    public Builder toBuilder() {
        return new Builder().values(values);
    }

    // ---------------------------------------------------------------------------------------------

    /**
     * Builder for {@link IdsQuery}.
     */

    public static class Builder extends QueryBase.AbstractBuilder<Builder> implements ObjectBuilder<IdsQuery> {
        @Nullable
        private List<String> values;

        /**
         * API name: {@code values}
         * <p>
         * Adds all elements of <code>list</code> to <code>values</code>.
         */
        public final Builder values(List<String> list) {
            this.values = _listAddAll(this.values, list);
            return this;
        }

        /**
         * API name: {@code values}
         * <p>
         * Adds one or more values to <code>values</code>.
         */
        public final Builder values(String value, String... values) {
            this.values = _listAdd(this.values, value, values);
            return this;
        }

        @Override
        protected Builder self() {
            return this;
        }

        /**
         * Builds a {@link IdsQuery}.
         *
         * @throws NullPointerException
         *             if some of the required fields are null.
         */
        public IdsQuery build() {
            _checkSingleUse();

            return new IdsQuery(this);
        }
    }

    // ---------------------------------------------------------------------------------------------

    /**
     * Json deserializer for {@link IdsQuery}
     */
    public static final JsonpDeserializer<IdsQuery> _DESERIALIZER = ObjectBuilderDeserializer.lazy(
        Builder::new,
        IdsQuery::setupIdsQueryDeserializer
    );

    protected static void setupIdsQueryDeserializer(ObjectDeserializer<IdsQuery.Builder> op) {
        setupQueryBaseDeserializer(op);
        op.add(Builder::values, JsonpDeserializer.arrayDeserializer(JsonpDeserializer.stringDeserializer()), "values");

    }

}

==> opensearch-java-2.18.0-sources.jar: org/opensearch/client/opensearch/_types/query_dsl/IdsQuery.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

package org.opensearch.client.opensearch._types.query_dsl;

import jakarta.json.stream.JsonGenerator;
import java.util.List;
import java.util.function.Function;
import javax.annotation.Nullable;
import org.opensearch.client.json.JsonpDeserializable;
import org.opensearch.client.json.JsonpDeserializer;
import org.opensearch.client.json.JsonpMapper;
import org.opensearch.client.json.ObjectBuilderDeserializer;
import org.opensearch.client.json.ObjectDeserializer;
import org.opensearch.client.util.ApiTypeHelper;
import org.opensearch.client.util.ObjectBuilder;

// typedef: _types.query_dsl.IdsQuery

@JsonpDeserializable
public class IdsQuery extends QueryBase implements QueryVariant {
    private final List<String> values;

    // ---------------------------------------------------------------------------------------------

    private IdsQuery(Builder builder) {
        super(builder);

        this.values = ApiTypeHelper.unmodifiable(builder.values);

    }

    public static IdsQuery of(Function<Builder, ObjectBuilder<IdsQuery>> fn) {
        return fn.apply(new Builder()).build();
    }

    /**
     * Query variant kind.
     */
    @Override
    public Query.Kind _queryKind() {
        return Query.Kind.Ids;
    }

    /**
     * API name: {@code values}
     */
    public final List<String> values() {
        return this.values;
    }

    protected void serializeInternal(JsonGenerator generator, JsonpMapper mapper) {

        super.serializeInternal(generator, mapper);
        if (ApiTypeHelper.isDefined(this.values)) {
            generator.writeKey("values");
            generator.writeStartArray();
            for (String item0 : this.values) {
                generator.write(item0);

            }
            generator.writeEnd();

        }

    }

    public Builder toBuilder() {
        return toBuilder(new Builder()).values(values);
    }

    // ---------------------------------------------------------------------------------------------

    /**
     * Builder for {@link IdsQuery}.
     */

    public static class Builder extends QueryBase.AbstractBuilder<Builder> implements ObjectBuilder<IdsQuery> {
        @Nullable
        private List<String> values;

        /**
         * API name: {@code values}
         * <p>
         * Adds all elements of <code>list</code> to <code>values</code>.
         */
        public final Builder values(List<String> list) {
            this.values = _listAddAll(this.values, list);
            return this;
        }

        /**
         * API name: {@code values}
         * <p>
         * Adds one or more values to <code>values</code>.
         */
        public final Builder values(String value, String... values) {
            this.values = _listAdd(this.values, value, values);
            return this;
        }

        @Override
        protected Builder self() {
            return this;
        }

        /**
         * Builds a {@link IdsQuery}.
         *
         * @throws NullPointerException
         *             if some of the required fields are null.
         */
        public IdsQuery build() {
            _checkSingleUse();

            return new IdsQuery(this);
        }
    }

    // ---------------------------------------------------------------------------------------------

    /**
     * Json deserializer for {@link IdsQuery}
     */
    public static final JsonpDeserializer<IdsQuery> _DESERIALIZER = ObjectBuilderDeserializer.lazy(
        Builder::new,
        IdsQuery::setupIdsQueryDeserializer
    );

    protected static void setupIdsQueryDeserializer(ObjectDeserializer<IdsQuery.Builder> op) {
        setupQueryBaseDeserializer(op);
        op.add(Builder::values, JsonpDeserializer.arrayDeserializer(JsonpDeserializer.stringDeserializer()), "values");

    }

}
